#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_name   ice

%define flavor php8%{nil}
%if "%{flavor}" == "" || (0%{?suse_version} >= 1550 && "%{flavor}" == "php7")
%define php_name php
ExclusiveArch:  do-not-build
%else
%define php_name %{flavor}
%endif
%if 0%{?suse_version} <= 1500
%define php_extdir  %(%{__php_config} --extension-dir)
%define php_cfgdir  %{_sysconfdir}/%{php_name}/conf.d
%endif
%define php74 %(%{__php} -r "echo version_compare('%{php_version}', '7.4.0');")

Name:           %{php_name}-%{pkg_name}
%if "%{flavor}" == "php8" || (0%{php74} >= 0)
Version:        1.10.1
%else
Version:        1.7.0
%endif
Release:        8.2
Summary:        PHP framework delivered as C extension
License:        BSD-3-Clause
Group:          Development/Libraries/PHP
URL:            http://www.iceframework.org/
Source0:        https://pecl.php.net/get/%{pkg_name}-1.10.1.tgz
Source1:        https://pecl.php.net/get/%{pkg_name}-1.7.0.tgz
Source2:        php-%{pkg_name}-rpmlintrc
BuildRequires:  %{php_name}-ctype
BuildRequires:  %{php_name}-devel
BuildRequires:  %{php_name}-mbstring
BuildRequires:  %{php_name}-mysql
BuildRequires:  %{php_name}-openssl
BuildRequires:  %{php_name}-pdo
BuildRequires:  %{php_name}-tokenizer
BuildRequires:  gcc
BuildRequires:  re2c
%if "%{flavor}" == "php8"
BuildRequires:  %{php_name} < 8.3
%else
BuildRequires:  %{php_name}-json
Requires:       %{php_name}-json
%endif

%description
ICE is a PHP framework delivered as C extension. You do not need
learn or use the C language, since the functionality is exposed as
PHP classes.

%prep
%if "%{flavor}" == "php8" || (0%{php74} >= 0)
%setup -q -n %{pkg_name}-%{version}
%else
%setup -q -n %{pkg_name}-%{version} -T -b 1
%endif

%build
export CFLAGS="%{optflags} -fvisibility=hidden"
%{__phpize}
%configure --enable-%{pkg_name}
%make_build

%install
%make_install INSTALL_ROOT=%{buildroot}
mkdir -p %{buildroot}%{php_cfgdir}
cat > %{buildroot}%{php_cfgdir}/%{pkg_name}.ini <<EOF
; comment out next line to disable %{pkg_name} extension in php
extension = %{pkg_name}.so
EOF

%files
%defattr(0644,root,root,-)
%license LICENSE
%config(noreplace) %{php_cfgdir}/%{pkg_name}.ini
%{php_extdir}/%{pkg_name}.so

%changelog
* Sat Apr  1 2023 Mariusz Laczak <mruz@poczta.onet.pl>
- Use latest version on php 7.4
* Sun Feb 19 2023 Mariusz Laczak <mruz@poczta.onet.pl>
- Ice 1.10.1
  * Arr, deprecation message fix #311
  * Loader, don't encode to utf8
  * Don't encode regex in route group count data generator
  * Passing null to parameter of type string is deprecated
  * Filter, sanitize string is deprecated
  * Model, serializable interface is deprecated fix #311
  * Auth, add login tests, logout fix
  * Composer, update zephir to 0.17.0
* Fri Feb 10 2023 Mariusz Laczak <mruz@poczta.onet.pl>
- Ice 1.10.0
  * PHP 8.2, add support fix #309
  * Install on Alpine fix #308
  * Update zephir-lang/zephir@57c522d
  * Update zephir parser to 1.5.3
  * Fix phpunit tests
* Mon Dec 12 2022 pgajdos@suse.com
- don't build php7 flavor for Factory (php7 is EOL upstream)
* Mon Jun 13 2022 Mariusz Laczak <mruz@poczta.onet.pl>
- Ice 1.9.0
  * PHP 8.1, add support fix #299
  * Switch to Github Actions fix #302
  * Update zephir to 0.16.0
  * Update zephir parser to 1.5.0
* Fri Jan 28 2022 Arjen de Korte <suse+build@de-korte.org>
- Update BuildRequires (php8-ice requires php8 < 8.1)
* Fri Mar 26 2021 Arjen de Korte <suse+build@de-korte.org>
- Ice 1.8.0 (php8 only)
  * Build, add support for php 8.0
  * Composer, update zephir to 0.13.0
  * Travis, no mongodb extension on nightly build
  * Tests, fix get related
  * Validation, fix type error in options
  * Model, fix type errors
* Wed Feb 17 2021 Arjen de Korte <suse+build@de-korte.org>
- Use _multibuild to also build for php8
- Use php_cfgdir and php_extdir macros to determine location of files
- Change upstream to PECL
- Remove obsolete patch (GCC supports SOURCE_DATE_EPOCH by default)
  - ice-notime.diff
- Ice 1.8.0alpha3 (php8 only)
  * Pecl, add build directories fix #271
  * Di, resolve default services in cli fix #295
  * Loader, register namespaces in the constructor fix #294
- Ice 1.8.0alpha2 (php8 only)
  * PHP 7.1, drop support, update phpunit to v8
  * Update zephir parser to 1.3.5
  * Zephir, use zephir-php8 branch
  * Pdo, fix associative array in order by
  * PHP 7.2 and 7.3, drop support
  * Tests, fix get related count and filter
  * Version, remove hyphen fix #292
* Sat Sep 26 2020 Mariusz Laczak <mruz@poczta.onet.pl>
- Ice 1.7.0
  * Url, add href and rel, deprecate getStatic, fix #231
  * Arr, add merge, deprecate replace, fix #228
  * View, set engine options, sleet compile fix #288
  * Validation, add exists validator #274
  * Db, count elements #277
  * Router, set routes must be explicitly called #282
  * Db, skip settings if not provided, fix #286
  * Auth file, fetch users from the options, fix #285
  * Sqlite, row count returns zero all the time, fix #283
* Sat Sep 12 2020 Mariusz Laczak <mruz@poczta.onet.pl>
- Ice 1.6.2
  * Model, get related record if field is null fix #275
  * Pagination, calculate if data is array or total is specified #273
  * Url, fixed getStatic() #193
* Sun May 10 2020 Mariusz Laczak <mruz@poczta.onet.pl>
- Ice 1.6.1
  * Update zephir, Model dafault rules fix #270
  * Build with recent GCC fix #266
  * Image, gd watermark fix #268
* Sat Apr 25 2020 Mariusz Laczak <mruz@poczta.onet.pl>
- Ice 1.6.0
  * Composer, update zephir to 0.12.18
  * Add the image component
  * Dump, recursion fix #265
  * PHP 7.0, drop support
  * Code cleanup
  * Update prototypes
  * Flash, add dismissible class
  * Dispatcher, continue if before returns a value
  * Update zephir parser to 1.3.4
  * Websocket, long message fix #262
* Sat Mar 14 2020 Mariusz Laczak <mruz@poczta.onet.pl>
- Ice 1.5.1
  * Composer, update zephir to 0.12.17
  * Auth, logout if no user fix #245
  * Model, get id fix #240
  * Auth, primary key fix #254
  * Websocket, encoding fix #260
  * Websocket, client connect fix #256
  * Self type hint fix #257
  * Console, color fix #258
* Sun Dec 22 2019 Mariusz Laczak <mruz@poczta.onet.pl>
- Ice 1.5.0
  * Build, add support for php 7.4
  * Composer, update zephir to 0.12.15 and zephir-parser to 1.3.3
  * PHP 5.6, drop support
* Wed Jan 16 2019 Mariusz Laczak <mruz@poczta.onet.pl>
- Ice 1.4.1
  * Build, add support for php 7.3 fix #251
  * Model, remove primary keys
  * Composer, update zephir to 0.11.9
  * Pdo, fixed sql error if emtpy filter
  * Model, refresh new data after update
  * Router, default router fix
* Tue Oct 30 2018 Mariusz Laczak <mruz@poczta.onet.pl>
- Ice 1.4.0
  * Exception, add a hook for pretty exceptions, fix #234
  * Session, robust start a session
  * Pdo, fixed things for different DBMS
  * Response, add toJson and toXml
  * Db, Model, rename the remove method to delete fix #221
  * Env, add environment helper
  * Auth, token enhancement, rename Model driver to Db
  * Router, refactor, rename old router to FastRouter
  * Auth, password hash enhancement
  * Di, hook bug fixed #208
  * Model, clear save status #205
  * Pdo, add query method fix #166
  * Model, fixed retry to save invalid model bug #202
  * Cli, add websocket component #201
  * Auth, make model classes in users configurable #199
  * Request, allow for empty string on get, post #197
  * Model, enhanced and bugs fix #185
  * Pdo, make it competitable with other dbms #188
  * Di, resolve bug fix #190
  * View, allow to render file with specific engine
  * Tests, add db and model tests
  * Dispatcher, add reset
  * Always return this from setters
  * Response, send file
  * App, add new module to the app
  * App, allow to render page without main layout fix #169
  * Response, set response content in controller fail fix #168
  * Request, implement interface
  * Config, load config from php file
  * PHP, fix declaration errors
  * Travis, update to xenial dist
  * Composer, use zephir v0.11.0 and zephir-parser v1.1.2
  * View, stop finding view when it meets the right engine and file
  * Modules, use loader from di and pass it to autoloaders fix #156
  * Loader, no namespace classes loading for the loader fix #154
* Wed Mar 28 2018 jengelh@inai.de
- Replace %%__-type macro indirections.
- Ensure neutrality of descriptions.
* Sun Mar 25 2018 mruz@poczta.onet.pl
- Ice 1.3.0
  * Model, add db service name as a property
  * Db, add options, oracle fix #150
  * Dump, use the reflection class instead of each function
  * PHP 5.5, drop support
  * Travis, enable PHP 7.2, remove legacy mongo
  * Composer, use working zephir
  * Assets, memory observe fix phalcon/zephir#1538
* Sat May 20 2017 mruz@poczta.onet.pl
- Ice 1.2.11
  * Tag, make public input
  * Db, fix mongo driver
* Thu Mar 30 2017 mruz@poczta.onet.pl
- Ice 1.2.10
  * Auth, facebook fix
* Fri Feb 24 2017 mruz@poczta.onet.pl
- Ice 1.2.9
  * Unique validator, fix mongodb
* Sat Feb 18 2017 mruz@poczta.onet.pl
- Ice 1.2.8
  * Facebook, add fields to API call
* Sat Feb 18 2017 mruz@poczta.onet.pl
- Ice 1.2.7
  * Social auth, get scope from options, use static url
* Fri Feb 10 2017 mruz@poczta.onet.pl
- Ice 1.2.6
  * Unique, fix mongodb driver
  * Mongodb, fix timestamp if value is NULL on getDateTime
  * Tag, add end_form()
  * Validators, update doc
  * Validation, fix revalidate, add more tests
* Sun Jan 22 2017 mruz@poczta.onet.pl
- Ice 1.2.5
  * Model, set rules if there is no validation rules on create
  * Unique, fix case insensitive on mongodb
  * Url, fix uri starts with # or ?
  * Fix memory leak in preg_match
  * Auth, add force login
* Sun Jan 15 2017 mruz@poczta.onet.pl
- Ice 1.2.4
  * Model, add autoincrement property
* Sun Jan  8 2017 mruz@poczta.onet.pl
- Ice 1.2.3
  * Mongodb, timestamp fix
* Sat Nov 19 2016 mruz@poczta.onet.pl
- Ice 1.2.2
  * DB, detect timestamp on toDateTime
  * Exception, allow for Throwable in PHP7
* Sat Nov 12 2016 mruz@poczta.onet.pl
- Ice 1.2.1
  * Db, remove legacy mongo from php 7
  * Digit validator, allow for int
  * Dump, add plain text attribute
  * Model, get date time
  * Mongodb, result as associative array
* Mon Sep  5 2016 mruz@poczta.onet.pl
- Ice 1.2.0 build 2
* Mon Aug 29 2016 mruz@poczta.onet.pl
- Ice 1.2.0
  * Db, add mongodb driver
  * Validation, translate fields on With validator fix #123
  * Url, uri starts with // fix #121
* Wed Jun 15 2016 mruz@poczta.onet.pl
- Ice 1.1.5
  * Router, fastRoute code improvements
  * Di, fix url auto-resolving
  * Response, move messages to function, remove di property
  * Router, add default routes, remove di property
  * Dump, add skip di property
  * FastRoute, fix #120 and update to nikic/FastRoute@30470b6
  * Copyright, update year
  * Sleet, allow for multi-line tags, fix #118
* Fri Jun  3 2016 mruz@poczta.onet.pl
- Ice 1.1.4
  * Pdo, change where to protected, fix #116
  * View, add setLayout alias of setMainView
  * Response, detect redirect loop
  * Assets, add collections
  * Tag, allow to clear meta tags
  * Flash, allow to overwrite options later
  * Validation, merge revalidate into validate
  * Validation, add revalidate method
  * Tag, Pagination, services are predefined
  * Validation, use arr object to store data
  * Arr, add only() and getValue() methods
  * View, looking for a view in multiple dirs if viewsDir is an array
  * Build, change directories to lowercase
* Thu May  5 2016 mruz@poczta.onet.pl
- Remove building zephir-parser
* Thu May  5 2016 jengelh@inai.de
- Add ice-notime.diff: drop __DATE__/__TIME__ from build to
  please rpmlint.
- Avoid doing anything but %%setup and %%patch in %%prep to not
  upset quilt when doing patch work.
- Fix SLE11 build by adding a BuildRoot: line.
* Wed May  4 2016 jengelh@inai.de
- Use Source URL; drop redundant %%clean section
* Tue Apr 26 2016 mruz@poczta.onet.pl
- Ice 1.1.3
  * Loader, fix php7 refcount zephir/issues/1140
  * Pagination, get current URL if uri is false
* Fri Mar 11 2016 mruz@poczta.onet.pl
- Ice 1.1.2
  * Dispatcher, add limit of forwards
  * Sleet parser, add NEW, INSTANCEOF tokens
  * File validator, doc fix
  * Pagination, add ability to change li, a, span HTML class
  * Filter, add boolean filter
* Sat Jan 30 2016 mruz@poczta.onet.pl
- Ice 1.1.1
  * Di, return null if type of service is null
  * Crypt, use setter
  * Pdo, add detecting IN condition, fix #102
* Tue Jan 26 2016 mruz@poczta.onet.pl
- Ice 1.1.0
  * Services, update to auto-resolving
  * Text, remove static from random method
  * Di, add auto-resolving services and constructor parameter fix #99
* Sun Jan  3 2016 mruz@poczta.onet.pl
- Ice 1.0.37
  * The json-c is not needed anymore
  * Tag, fix #97 overwrite radio values
  * Install extension, cd fix
  * Update readme
  * Travis, update token
  * Travis, zephir fullclean is unnecessary
  * Build, get only generated files by zephir
  * Ignore ext/ directory
  * Delete ext/ directory
  * Travis, implement automated source regenerating
* Thu Nov 26 2015 mruz@poczta.onet.pl
- Ice 1.0.36
  * Core, use the latest zephir
  * Pdo, don't require pdo extension to build/run ice
  * Auth social, allow to store twitter access token in the session
* Thu Nov  5 2015 mruz@poczta.onet.pl
- Ice 1.0.35
  * Mvc, add service
* Fri Oct 16 2015 mruz@poczta.onet.pl
- Ice 1.0.34
  * Unique, add case insensitive
* Wed Oct 14 2015 mruz@poczta.onet.pl
- Ice 1.0.33
  * Pagination, first page fix
* Tue Oct  6 2015 mruz@poczta.onet.pl
- Ice 1.0.32
  * Model, unset primary key on create
  * Model, don't unset primary keys on multi column
* Fri Oct  2 2015 mruz@poczta.onet.pl
- Ice 1.0.31
  * Travis, remove valgrind
  * Travis, migrate to new container infrastructure
  * Core, use the latest zephir
* Fri Oct  2 2015 mruz@poczta.onet.pl
- Ice 1.0.30
  * Model, update and valid fields to save
* Tue Sep 29 2015 mruz@poczta.onet.pl
- Ice 1.0.29
  * Console, fix argument 1 passed to __construct() must be an instance of Ice\Cli\Di
  * Model, create/update improvements
* Fri Sep 11 2015 mruz@poczta.onet.pl
- Ice 1.0.28
  * Access, register the app/console itself as a service
  * Model, add options for loadOne findOne
* Sat Sep  5 2015 mruz@poczta.onet.pl
- Ice 1.0.27
  * Dispatcher, gets variable from params attribute applying filters if needed
  * Model, allow to apply Validation on update, fetch validation's values on create
  * Auth File, return Arr object on getUser()
  * Pagination, move the repeated data to the prepareButton method
* Mon Aug 31 2015 mruz@poczta.onet.pl
- Ice 1.0.26
  * Auth, return null if user not found during login
  * Db, create driver for given options
* Wed Aug 19 2015 mruz@poczta.onet.pl
- Ice 1.0.25
  * Assets, fix option name for source
* Wed Aug 19 2015 mruz@poczta.onet.pl
- Ice 1.0.24
  * Tag, add meta tag
* Tue Aug 18 2015 mruz@poczta.onet.pl
- Ice 1.0.23
  * Model, findOne make sure to return false if result not found
  * Dispatcher, forward force backward compatibility
  * Dispatcher, add force forward option
* Wed Aug  5 2015 mruz@poczta.onet.pl
- Ice 1.0.22
  * Response, return object on redirect
* Mon Aug  3 2015 mruz@poczta.onet.pl
- Ice 1.0.21
  * Url, mailto fix
  * Model, add options on getRelated method
* Thu Jul 30 2015 mruz@poczta.onet.pl
- Ice 1.0.20
  * Assets, add forceMinified option
* Thu Jul 30 2015 mruz@poczta.onet.pl
- Ice 1.0.19
  * Assets, do not add a version if not specified
  * Filter js, clear the output
  * Assets, add helper to manage css/js resources
  * Filter, implement jsmin
* Thu Jul 23 2015 mruz@poczta.onet.pl
- Ice 1.0.18
  * Validation, add getValues method for getting all filtered values
* Wed Jul 22 2015 mruz@poczta.onet.pl
- Ice 1.0.17
  * Dump, skip debuging di, fix detecting private/protected properties
* Sat Jul 18 2015 mruz@poczta.onet.pl
- Ice 1.0.16
  * Zephir, use the working wersion
  * Route, update fast route to the latest commit
  * Model, add getRules method
* Sat Jun 27 2015 mruz@poczta.onet.pl
- Ice 1.0.15
  * PSR-2, Properties name should not be prefixed with an underscore to indicate visibility
* Fri Jun 26 2015 mruz@poczta.onet.pl
- Ice 1.0.14
  * Session, PHP Strict Standards fix
  * Tag, add radio input
  * Validation, docs & examples fixes
* Sun Jun  7 2015 mruz@poczta.onet.pl
- Ice 1.0.13
  * Mongo, select document by MongoId
  * Validation, add doc with examples
  * Tag, add doc with examples
* Thu May  7 2015 mruz@poczta.onet.pl
- Ice 1.0.12
  * Response, add setContent method
  * Mvc app, get the response from handler
* Tue May  5 2015 mruz@poczta.onet.pl
- Ice 1.0.11
  * Filter, get propper type fix #58
  * Unique validator, mongo id fix #59
- Ice 1.0.10
  * FastRoute, cached dispatcher fix
- Ice 1.0.9
  * Di, improve performance on getting services & use the latest Zephir
* Fri Apr 10 2015 mruz@poczta.onet.pl
- Ice 1.0.8
  * Core, use the latest zephir
  * Auth, improvements for mongo driver
  * I18n, add global alias to translate function
* Tue Apr  7 2015 mruz@poczta.onet.pl
- Ice 1.0.7
  * Di, set root path in the constructor
  * Back to working zephir
* Sat Mar 28 2015 mruz@poczta.onet.pl
- Ice 1.0.6
  * Model, change serialize/unserialize to json_encode/json_decode, fix #37
  * Exception, add getFullTraceAsString method
* Thu Mar 26 2015 mruz@poczta.onet.pl
- Ice 1.0.5
  * Config ini, better decode values due to parse_ini_file() has a poor implementation
  * Mongo driver, compatybility with Pdo
  * Get the latest Zephir
* Fri Mar 20 2015 mruz@poczta.onet.pl
- Ice 1.0.4
  * Db, mongo driver fixes
* Fri Mar  6 2015 mruz@poczta.onet.pl
- Ice 1.0.3
  * Module, simplify declaration of one module application
* Wed Mar  4 2015 mruz@poczta.onet.pl
- Ice 1.0.2
  * Config, constructor improvements
  * Travis, try to add PHP 7
  * FastRoute, support adding the same route for multiple HTTP methods
* Mon Mar  2 2015 mruz@poczta.onet.pl
- Ice 1.0.1
  * I18n, translate with different contexts eg. for male/female or plural form
* Thu Feb 26 2015 mruz@poczta.onet.pl
- Ice 1.0.0
  * Get the latest zephir
* Tue Feb 17 2015 mruz@poczta.onet.pl
- Ice 1.0.0-rc3
  * Auth social, allow refreshing access token from google & facebook
* Tue Feb 17 2015 mruz@poczta.onet.pl
- Ice 1.0.0-rc2
  * Social model, fix alias
  * PHPDoc, fix examples in <code>
* Mon Feb 16 2015 mruz@poczta.onet.pl
- Ice 1.0.0-rc1
  * Auth, add sign in with Facebook, Google, Twitter
  * Composer, update phpunit
  * Readme, add badges
* Thu Feb  5 2015 mruz@poczta.onet.pl
- Ice 1.0.0-beta2
  * Model, unserialize fix #37
  * Model, validation's getMessages returns Arr object
* Fri Jan 30 2015 mruz@poczta.onet.pl
- Ice 1.0.0-beta1
  * Get the latest zephir, Model, add extra validation on update
  * Documentation, add some comments for the PHPDoc
  * Travis, run gdb after faliure
  * Exception, exit with 1 after handle
* Sun Jan 25 2015 mruz@poczta.onet.pl
- Ice 1.0.0-alpha2
  * Auth, logout and remove all tokens for user
* Sat Jan 24 2015 mruz@poczta.onet.pl
- Ice dev build 25012015
  * Exception, add handlers for error/exception/shutdown
* Sun Jan 11 2015 mruz@poczta.onet.pl
- Ice 1.0.0-alpha1
  * Version, Ice 1.0.0-alpha1
  * Request, remove _url from GET during getQuery
  * Pagination, translate improvements
  * Validation, move translate into validators
  * Tests, sleet parser skip tag
  * View, angular fix, add comment block
  * Model, unset primary key on create/update
* Fri Dec 19 2014 mruz@poczta.onet.pl
- Ice dev build 19122014
  * Auth, fix delete expired tokens
  * Filter, minify css and base for minify js
  * I18n, add iso method
  * Unique validator fix
  * App, add hooks
  * Flash, getMessage fix
* Fri Dec 12 2014 mruz@poczta.onet.pl
- Ice dev build 12122014
  * Console, add colored echo and improvements to CLI router
  * App, remove unnecessary declaration
  * Dispatcher, move module settings to the dispatcher
  * PDO, return false if row is not fetched
  * Tag, use url service if available
  * Filter, repeats fix
  * PDO, order by typo fix
* Tue Dec  9 2014 mruz@poczta.onet.pl
- Ice dev build 09122014
  * Sleet parser, short if and functions fix
  * CLI response fix, remove defaultModule from App
  * Validation, file validator message
  * Model, apply custom validation and filters
  * Validation, translate labels and doc
  * Request, add hasFile() method
  * Tag, autocheck fix
* Sat Dec  6 2014 mruz@poczta.onet.pl
- Ice dev build 06122014
  * Di fetch, remove DiInterface
  * Pagination improvements
  * Tag, HTML <select> Tag
* Thu Dec  4 2014 mruz@poczta.onet.pl
- Ice dev build 04122014
* Sat Nov 29 2014 mruz@poczta.onet.pl
- Ice dev build 29112014v2
* Thu Nov 27 2014 mruz@poczta.onet.pl
- Ice dev build 27112014
* Mon Nov 17 2014 mruz@poczta.onet.pl
- Ice release 1.0.0dev 17112014
* Sat Nov 15 2014 mruz@poczta.onet.pl
- Ice release 1.0.0dev 15112014
* Sat Nov 15 2014 mruz@poczta.onet.pl
- Ice release 1.0.0-dev 15112014
